#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-CB4PSp35b8J5G55rlkFnhd
key:                  gitit-0.15.1.2-CB4PSp35b8J5G55rlkFnhd
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  328829b9d286e037aafcef09c41268bb
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-CB4PSp35b8J5G55rlkFnhd
depends:
    HStringTemplate-0.8.8-f34WW85xOu4BBMbP8oGgM
    HTTP-4000.4.1-56k6XzW1iWd5pdtORF53u7
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1
    base64-bytestring-1.2.1.0-EmY0767ffFE8tBeH3slcY
    blaze-html-0.9.2.0-KqwG3G8bIEdCBkJGh5vAX5 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-C9IqPcbwLQN5nvftko7jOb
    feed-1.3.2.1-I8ojaYCwmuJHrKLfDzaJxz filepath-1.4.300.1
    filestore-0.6.5.1-DpXUabFWHCTHEmfmgYwYtw ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-COh9vm23uU1KkE2ZBCEo7b
    hoauth2-2.14.0-3uKDq13JH9a3fzel5hnRaA
    hslogger-1.3.2.0-54YAScJpHPq1vuNws5fcKt
    http-client-tls-0.3.6.4-63NdgoH5NGbC0F7SbjBwuZ
    http-conduit-2.3.9.1-KjEJYPYZO4SBblo4w3yP8J
    json-0.10-5Jyxohhk15QHDvOzGdZ54X mtl-2.3.1
    network-3.1.4.0-9dONp0onFcbAlDBEoFNGkb
    network-bsd-2.8.1.0-3jmtZ8zx89NKRdR2JoHFYk
    network-uri-2.6.4.2-F4vpljQpQbT2777eQcDCfi
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-7OJ6K6Xg4Zr4cfKqi7dSdw
    pandoc-types-1.23.1-t3iMvUOsvaKZsdEuTF3no parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-1Uit38DFsvW5UeAKObGtgy
    recaptcha-0.1.0.4-KPNnwjk4WKRGSXg3w5iv9X
    safe-0.3.21-6CaTNq5Bbh3B41S6S9jGxQ
    skylighting-0.14.4-8AKwQJiQRg555azP73rsRf
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-9nTxFCe6QUcL36iCSC2LiM
    tagsoup-0.14.8-5JDJWoQxVToFGNOl7vgKsj
    temporary-1.3-C4AWJcx6OU755V1dgCzpdm text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-8SfJi4NBb2ETgt0TdQqjs
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16.1-A1XTGtbTbec3kAFoJMDYR8 xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-KzsVcANkifF2lJJF05P91u
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-JbGMpKxXmOd8BUJj0Z07ii
    zlib-0.7.0.0-K5bETTrFWiS11n1O8Dz4v6

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

